@@ -100,7 +100,7 @@ struct _MousepadApplication
   GtkSourceSpaceLocationFlags  space_location_flags;
 
   /* command line options */
-  gint             opening_mode;
+  gint             opening_mode, line, column;
   MousepadEncoding encoding;
 };
 
@@ -127,6 +127,18 @@ static const GOptionEntry option_entries[] =
     G_OPTION_ARG_NONE, NULL,
     N_("Display a list of possible encodings to open files"), NULL
   },
+  {
+    "line", 'l', G_OPTION_FLAG_NONE,
+    G_OPTION_ARG_INT, NULL,
+    N_("Line number the cursor to position to (LINE > 0 from top, LINE < 0 from bottom)"),
+    N_("LINE")
+  },
+  {
+    "column", 'c', G_OPTION_FLAG_NONE,
+    G_OPTION_ARG_INT, NULL,
+    N_("Column number the cursor to position to (COLUMN >= 0 from start, COLUMN < 0 from end)"),
+    N_("COLUMN")
+  },
   {
     "disable-server", '\0', G_OPTION_FLAG_NONE,
     G_OPTION_ARG_NONE, NULL,
@@ -319,6 +331,8 @@ mousepad_application_init (MousepadApplication *application)
   application->space_location_flags = GTK_SOURCE_SPACE_LOCATION_ALL;
   application->opening_mode = TAB;
   application->encoding = mousepad_encoding_get_default ();
+  application->line = 0;
+  application->column = 0;
 
   /* default application name */
   g_set_application_name (_("Mousepad"));
@@ -377,9 +391,10 @@ static gint
 mousepad_application_handle_local_options (GApplication *gapplication,
                                            GVariantDict *options)
 {
-  MousepadEncoding   encoding;
-  GApplicationFlags  flags;
-  GError            *error = NULL;
+  MousepadApplication *application = MOUSEPAD_APPLICATION (gapplication);
+  MousepadEncoding     encoding;
+  GApplicationFlags    flags;
+  GError              *error = NULL;
 
   if (g_variant_dict_contains (options, "version"))
     {
@@ -430,6 +445,9 @@ mousepad_application_handle_local_options (GApplication *gapplication,
       g_application_set_flags (gapplication, flags | G_APPLICATION_NON_UNIQUE);
     }
 
+  /* transfer encoding from remote to primary instance via the options dictionary */
+  g_variant_dict_insert (options, "encoding", "u", application->encoding);
+
   /* chain up to startup (primary instance) or command_line (remote instance) */
   return -1;
 }
@@ -732,6 +750,17 @@ mousepad_application_command_line (GApplication            *gapplication,
   else
     application->opening_mode = MOUSEPAD_SETTING_GET_ENUM (OPENING_MODE);
 
+  /* retrieve encoding from the remote instance */
+  g_variant_dict_lookup (options, "encoding", "u", &(application->encoding));
+
+  /* get line and column number from command line */
+  g_variant_dict_lookup (options, "line", "i", &(application->line));
+  g_variant_dict_lookup (options, "column", "i", &(application->column));
+
+  /* for user line starts from 1 but for gtk line starts from 0 */
+  if (application->line > 0)
+    --application->line;
+
   /* extract filenames */
   g_variant_dict_lookup (options, G_OPTION_REMAINING, "^a&ay", &filenames);
 
@@ -838,11 +867,13 @@ mousepad_application_open (GApplication  *gapplication,
 
           /* open the files */
           opened = mousepad_window_open_files (MOUSEPAD_WINDOW (window), valid_files, valid,
-                                               application->encoding, FALSE);
+                                               application->encoding, application->line,
+                                               application->column, FALSE);
 
-          /* if at least one file was finally opened, show the window */
+          /* if at least one file was finally opened, present the window, so that it requires
+           * attention if already open */
           if (opened > 0)
-            gtk_widget_show (window);
+            gtk_window_present (GTK_WINDOW (window));
           else if (GTK_IS_WIDGET (window))
             gtk_widget_destroy (window);
         }
@@ -856,7 +887,8 @@ mousepad_application_open (GApplication  *gapplication,
 
               /* open the file */
               opened = mousepad_window_open_files (MOUSEPAD_WINDOW (window), valid_files + n, 1,
-                                                   application->encoding, FALSE);
+                                                   application->encoding, application->line,
+                                                   application->column, FALSE);
 
               /* if the file was finally opened, show the window */
               if (opened > 0)
